@@ -513,10 +513,17 @@ class FIMAPI(object):
             dictionary
             '''
             net_id = descriptor.get('uuid')
+            nets = self.list()
+            ni = [x for x in nets if x['uuid'] == net_id]
+            if len(ni) > 0:
+                    d = ni[0]
+            else:
+                raise ValueError('Network  {} not present in catalog'.format(net_id))
+
             net = self.connector.glob.actual.get_node_network(self.sysid, self.tenantid, nodeid, net_id)
             if net is not None:
                 return net
-            res = self.connector.glob.actual.create_network_in_node(self.sysid, self.tenantid, nodeid, descriptor)
+            res = self.connector.glob.actual.create_network_in_node(self.sysid, self.tenantid, nodeid, net_id)
             if res.get('error') is not None:
                 raise ValueError('Got  Error {} with message {}'.format(res['error'], res['error_msg']))
             return res['result']
